/*
 * Copyright CERN 2021
 * Author: Juan David Gonzalez Cobas <dcobas _at_ cern.ch>
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

#include "fsi.h"

/** @file libfsi.c - implementation of ancillary functions in libfsi */
/**
 * @brief	set up a single channel configuration
 * @param[in]	h		- opaque lib handle/context
 * @param[in]	cfg		- a fsi_channel_config instance
 */
int fsi_channel_configure(FSI *h, struct fsi_channel_config *cfg)
{
	return fsi_channel_array_configure(h, cfg, 1);
}

/**
 * @brief	recover the result of measurement processing
 * @param[in]	h		- opaque lib handle/context
 * @param[out]	meas		- array of measurements
 * @param[out]	nchannels	- number of valid entries returned in meas
 */
int fsi_receive_measurements(FSI *h, struct fsi_channel_measurement meas[], int *nchannels)
{
    	return fsi_receive_measurements_timemout(h, meas, nchannels, 0);
}
